#import "ADEUMReactNative.h"
#import <React/RCTConvert.h>
#import <ADEUMInstrumentation/ADEumInstrumentation.h>

@interface CrashCallbackObject: NSObject <ADEumCrashReportCallback>

@property RCTResponseSenderBlock reactCrashRequestCallback;

@end

@implementation CrashCallbackObject

- (void)onCrashesReported:(NSArray<ADEumCrashReportSummary *> *)summaries {
  NSMutableArray *reactSummaries = [NSMutableArray array];

  for (ADEumCrashReportSummary *summary in summaries) {
    NSMutableDictionary *dict = [NSMutableDictionary dictionary];

    dict[@"crashId"] = summary.crashId;
    dict[@"exceptionName"] = summary.exceptionName;
    dict[@"exceptionReason"] = summary.exceptionReason;
    dict[@"signalName"] = summary.signalName;
    dict[@"signalCode"] = summary.signalCode;

    [reactSummaries addObject: dict];
  }

  self.reactCrashRequestCallback(@[reactSummaries]);
}
@end

@implementation RCTConvert (ADEumBreadcrumbVisibility)
RCT_ENUM_CONVERTER(ADEumBreadcrumbVisibility, (@{
  @"BREADCRUMB_VISIBILITY_CRASHES_ONLY" : @(ADEumBreadcrumbVisibilityCrashesOnly),
  @"BREADCRUMB_VISIBILITY_CRASHES_AND_SESSIONS" : @(ADEumBreadcrumbVisibilityCrashesAndSessions)
}), ADEumBreadcrumbVisibilityCrashesOnly, integerValue)
@end

@implementation RCTConvert (ADEumErrorSeverityLevel)
RCT_ENUM_CONVERTER(ADEumErrorSeverityLevel, (@{
  @"ERROR_SEVERITY_LEVEL_INFO" : @(ADEumErrorSeverityLevelInfo),
  @"ERROR_SEVERITY_LEVEL_WARNING" : @(ADEumErrorSeverityLevelWarning),
  @"ERROR_SEVERITY_LEVEL_CRITICAL" : @(ADEumErrorSeverityLevelCritical)
}), ADEumErrorSeverityLevelInfo, integerValue)
@end

@implementation RCTConvert (ADEumLoggingLevel)
RCT_ENUM_CONVERTER(ADEumLoggingLevel, (@{
  @"LOGGING_LEVEL_INFO" : @(ADEumLoggingLevelInfo),
  @"LOGGING_LEVEL_NONE" : @(ADEumLoggingLevelOff),
  @"LOGGING_LEVEL_VERBOSE" : @(ADEumLoggingLevelAll)
}), ADEumLoggingLevelInfo, integerValue)
@end

@implementation ADEUMReactNative {
  NSMutableDictionary<NSString *, id> *callTrackers;
  NSMutableDictionary<NSString *, ADEumSessionFrame *> *sessionFrames;
  NSMutableDictionary<NSString *, ADEumHTTPRequestTracker *> *customRequestTrackers;
  RCTResponseSenderBlock reactCrashRequestCallback;
  CrashCallbackObject *crashCallbackObject;
}

RCT_EXPORT_MODULE(ReactNativeAppdynamics)

- (instancetype)init {
  if (self = [super init]) {
    callTrackers = [NSMutableDictionary dictionary];
    sessionFrames = [NSMutableDictionary dictionary];
    customRequestTrackers = [NSMutableDictionary dictionary];
  }
  return self;
}

- (dispatch_queue_t)methodQueue
{
  return dispatch_get_main_queue();
}

+ (BOOL)requiresMainQueueSetup
{
  return YES;
}

- (NSDictionary *)constantsToExport
{
  return @{
    @"BREADCRUMB_VISIBILITY_CRASHES_AND_SESSIONS": @(ADEumBreadcrumbVisibilityCrashesAndSessions),
    @"BREADCRUMB_VISIBILITY_CRASHES_ONLY": @(ADEumBreadcrumbVisibilityCrashesOnly),
    @"ERROR_SEVERITY_LEVEL_CRITICAL": @(ADEumErrorSeverityLevelCritical),
    @"ERROR_SEVERITY_LEVEL_INFO": @(ADEumErrorSeverityLevelInfo),
    @"ERROR_SEVERITY_LEVEL_WARNING": @(ADEumErrorSeverityLevelWarning),
    @"LOGGING_LEVEL_INFO": @(ADEumLoggingLevelInfo),
    @"LOGGING_LEVEL_NONE": @(ADEumLoggingLevelOff),
    @"LOGGING_LEVEL_VERBOSE": @(ADEumLoggingLevelAll),
    // The iOS SDK doesn't expose `maxUserDataKeyValueLengthInChars` so we have to hardcode it below.
    @"MAX_USER_DATA_STRING_LENGTH": @(2048)
  };
}

RCT_EXPORT_METHOD(start:(NSDictionary *)config hybridAgentType:(NSString *)hybridAgentType hybridAgentVersion:(NSString *)hybridAgentVersion resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject)
{
  try {
    NSString* appKey = [RCTConvert NSString:config[@"appKey"]];
    ADEumAgentConfiguration *adeumConfig = [[ADEumAgentConfiguration alloc] initWithAppKey:appKey];
    if ([config objectForKey:@"applicationName"]) {
      adeumConfig.applicationName = [RCTConvert NSString:config[@"applicationName"]];
    }
    if ([config objectForKey:@"autoInstrument"]) {
      adeumConfig.enableAutoInstrument = [RCTConvert BOOL:config[@"autoInstrument"]];
    }
    if ([config objectForKey:@"collectorURL"]) {
      adeumConfig.collectorURL = [RCTConvert NSString:config[@"collectorURL"]];
    }
    if ([config objectForKey:@"screenshotURL"]) {
      adeumConfig.screenshotURL = [RCTConvert NSString:config[@"screenshotURL"]];
    }
    if ([config objectForKey:@"loggingLevel"]) {
      adeumConfig.loggingLevel = (ADEumLoggingLevel)[RCTConvert NSInteger:config[@"loggingLevel"]];
    }
    if ([config objectForKey:@"excludedURLPatterns"]) {
      adeumConfig.excludedUrlPatterns = [RCTConvert NSSet:config[@"excludedURLPatterns"]];
    }
    if ([config objectForKey:@"screenshotsEnabled"]) {
      adeumConfig.screenshotsEnabled = [RCTConvert BOOL:config[@"screenshotsEnabled"]];
    }
    if ([config objectForKey:@"jsAgentInjectionEnabled"]){
      adeumConfig.jsAgentEnabled = [RCTConvert BOOL:config[@"jsAgentInjectionEnabled"]];
    }
    if ([config objectForKey:@"jsAgentAjaxEnabled"]) {
      adeumConfig.jsAgentAjaxEnabled = [RCTConvert BOOL:config[@"jsAgentAjaxEnabled"]];
    }
    if ([config objectForKey:@"anrDetectionEnabled"]) {
      adeumConfig.anrDetectionEnabled = [RCTConvert BOOL:config[@"anrDetectionEnabled"]];
    }
    if ([config objectForKey:@"crashReportingEnabled"]) {
      adeumConfig.crashReportingEnabled = [RCTConvert BOOL:config[@"crashReportingEnabled"]];
    }
    if (reactCrashRequestCallback) {
      crashCallbackObject = [CrashCallbackObject new];
      crashCallbackObject.reactCrashRequestCallback = reactCrashRequestCallback;
      adeumConfig.crashReportCallback = crashCallbackObject;
    }

    // Disabled because it's not working properly. Users should fallback to manual tracking.
    adeumConfig.interactionCaptureMode = ADEumInteractionCaptureModeNone;

    [ADEumInstrumentation initWithConfiguration:adeumConfig a:hybridAgentType b:hybridAgentVersion];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to start instrumentation", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(leaveBreadcrumb:(NSString *)breadcrumb mode:(ADEumBreadcrumbVisibility)mode resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation leaveBreadcrumb:breadcrumb mode:mode];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to leave breadcrumb", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(createCrashReport:(NSString *)hybridExceptionData resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation createRawCrashReport:hybridExceptionData];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to create crash report", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(reportError:(NSString *)hybridExceptionData severity:(ADEumErrorSeverityLevel)severity resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation reportRawError:hybridExceptionData withSeverity:severity];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to report error", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(changeAppKey:(NSString *)appKey resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation changeAppKey:appKey];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to change app key", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(reportMetric:(NSString *)name value:(NSInteger)value resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation reportMetricWithName:name value:value];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to report metric", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(startTimer:(NSString *)name resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation startTimerWithName:name];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to start timer", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(stopTimer:(NSString *)name resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation stopTimerWithName:name];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to stop timer", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(beginCall:(NSString *)className methodName:(NSString *)methodName args:(NSArray *)args isStatic:(BOOL)isStatic resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    NSString *callId = [[NSUUID UUID] UUIDString];
    id tracker = [ADEumInstrumentation beginCall:className methodName:methodName withArguments:args];
    [callTrackers setObject:tracker forKey:callId];
    resolve(callId);
  } catch (NSException *e) {
    reject(@"Failed to start call tracking.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(endCallWithSuccess:(NSString *)callId data:(NSDictionary *)data resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    id tracker = [callTrackers objectForKey:callId];
    if (tracker) {
      [ADEumInstrumentation endCall:tracker withValue:[data objectForKey:@"result"]];
      [callTrackers removeObjectForKey:callId];
    }
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to end call tracking.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(endCallWithError:(NSString *)callId error:(NSDictionary *)error resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    id tracker = [callTrackers objectForKey:callId];
    if (tracker) {
      // There is no way to report a call ending in error on iOS, so we work around the problem by reporting a regular
      // endCall with a specific payload
      [ADEumInstrumentation endCall:tracker withValue:@{
        @"is_error": @(YES),
        @"message": [error objectForKey:@"message"],
        @"stackTrace": [error objectForKey:@"stack"]
      }];
    [callTrackers removeObjectForKey:callId];
    }
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to end call tracking.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(unblockScreenshots:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation unblockScreenshots];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to unblock screenshots.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(blockScreenshots:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation blockScreenshots];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to block screenshots.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(screenshotsBlocked:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    resolve([NSNumber numberWithBool:[ADEumInstrumentation screenshotsBlocked]]);
  } catch (NSException *e) {
    reject(@"Failed to check if screenshots are blocked.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(takeScreenshot:(RCTPromiseResolveBlock)resolve rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation takeScreenshot];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to take screenshot.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(setUserData:(NSString *)key value:(NSString *)value resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation setUserData:key value:value];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to set user data.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(removeUserData:(NSString *)key resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation removeUserData:key];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to remove user data.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(setUserDataNumber:(NSString *)key value:(double)value resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation setUserDataDouble:key value:value];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to set user data number.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(removeUserDataNumber:(NSString *)key resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation removeUserDataDouble:key];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to remove user data number.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(setUserDataBoolean:(NSString *)key value:(BOOL)value resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation setUserDataBoolean:key value:value];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to set user data boolean.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(removeUserDataBoolean:(NSString *)key resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation removeUserDataBoolean:key];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to remove user data boolean.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(setUserDataDate:(NSString *)key valueStr:(NSString *)valueStr resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    double value = atoll([valueStr UTF8String]);
    NSDate *date = [[NSDate date] initWithTimeIntervalSince1970:value/1000];
    [ADEumInstrumentation setUserDataDate:key value:date];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to set user data date.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(removeUserDataDate:(NSString *)key resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation removeUserDataDate:key];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to take remove user data date.", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(startNextSession:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation startNextSession];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to start next session", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(startSessionFrame:(NSString *)name resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    NSUUID *uuid = [NSUUID UUID];
    NSString *uuidString = [uuid UUIDString];
    ADEumSessionFrame *sessionFrame = [ADEumInstrumentation startSessionFrame:name];
    [sessionFrames setObject:sessionFrame forKey:uuidString];
    resolve(uuidString);
  } catch (NSException *e) {
    reject(@"Failed to create session frame", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(updateSessionFrameName:(NSString *) frameId name:(NSString *)name resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    ADEumSessionFrame *sessionFrame = [sessionFrames objectForKey:frameId];
    if (sessionFrame) {
      [sessionFrame updateName:name];
    }
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to create session frame", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(endSessionFrame:(NSString *) frameId resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    ADEumSessionFrame *sessionFrame = [sessionFrames objectForKey:frameId];
    if (sessionFrame) {
      [sessionFrame end];
      [sessionFrames removeObjectForKey:frameId];
    }
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to end session frame", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(trackScreenStart:(NSDictionary *) trackedScreen resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    NSUUID *uuid = [NSUUID UUID];
    // CDM-9000 TODO: Explore posibility of having type-safe object keys (with new RN
    // architecture)
    NSString *screenName = trackedScreen[@"screenName"];
    NSNumber *startDateUnix = trackedScreen[@"startDate"];
    NSDate *startDate = [NSDate dateWithTimeIntervalSince1970:[startDateUnix doubleValue] / 1000];
    [ADEumInstrumentation TrackPageStart:screenName uuid:uuid start:startDate];
    resolve([uuid UUIDString]);
  } catch (NSException *e) {
    reject(@"Failed to track page start", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(trackScreenEnd: (NSDictionary *) trackedScreen resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    NSString *screenName = trackedScreen[@"screenName"];
    NSString *uuidString = trackedScreen[@"uuidString"];
    NSUUID *uuid = [[NSUUID alloc] initWithUUIDString:uuidString];

    NSNumber *startDateUnix = trackedScreen[@"startDate"];
    NSDate *startDate = [NSDate dateWithTimeIntervalSince1970:[startDateUnix doubleValue] / 1000];

    NSNumber *endDateUnix = trackedScreen[@"endDate"];
    NSDate *endDate = [NSDate dateWithTimeIntervalSince1970:[endDateUnix doubleValue] / 1000];

    [ADEumInstrumentation TrackPageEnd:screenName uuid:uuid start:startDate end:endDate];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to track page end", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(shutdownAgent:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation shutdownAgent];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to shutdown agent", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(restartAgent:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    [ADEumInstrumentation restartAgent];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to restart agent", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(setCrashReportCallback:(RCTResponseSenderBlock) cb) {
  reactCrashRequestCallback = cb;
}

#pragma Manual Request Tracking

RCT_EXPORT_METHOD(getServerCorrelationHeaders:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    NSDictionary *headers = [ADEumServerCorrelationHeaders generate];
    resolve(headers);
  } catch (NSException *e) {
    reject(@"Failed to get server correlation headers", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(getRequestTrackerWithUrl:(NSString *) urlString resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    NSURL* url = [NSURL URLWithString:urlString];
    NSString *uuidString = [[NSUUID UUID] UUIDString];
    ADEumHTTPRequestTracker *tracker = [ADEumHTTPRequestTracker requestTrackerWithURL:url];
    customRequestTrackers[uuidString] = tracker;
    if (tracker) {
      resolve(uuidString);
    } else {
      reject(@"Failure", @"Failed to create the request tracker", nil);
    }
  } catch (NSException *e) {
    reject(@"Failed to create the request tracker", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(setRequestTrackerErrorInfo:(NSString *)trackerId errorDict:(NSDictionary *)errorDict resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    ADEumHTTPRequestTracker *tracker = customRequestTrackers[trackerId];
    if (tracker) {
      NSError* error = [NSError errorWithDomain:@"Manual request tracker" code:0 userInfo:errorDict];
      tracker.error = error;
    }
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to set request tracker error info", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(setRequestTrackerStatusCode:(NSString *)trackerId statusCode:(nonnull NSNumber *)statusCode resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    ADEumHTTPRequestTracker *tracker = customRequestTrackers[trackerId];
    if (tracker) {
      tracker.statusCode = statusCode;
    }
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to set request tracker status code", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(setRequestTrackerResponseHeaders:(NSString *)trackerId responseHeaders: (NSDictionary *)responseHeaders resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    ADEumHTTPRequestTracker *tracker = customRequestTrackers[trackerId];
    if (tracker) {
      tracker.allHeaderFields = responseHeaders;
    }
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to set request tracker response headers", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(setRequestTrackerRequestHeaders:(NSString *)trackerId requestHeaders:(NSDictionary *)requestHeaders resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    ADEumHTTPRequestTracker *tracker = customRequestTrackers[trackerId];
    if (tracker) {
      tracker.allRequestHeaderFields = requestHeaders;
    }
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to set request tracker request headers", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(requestTrackerReport:(NSString *)trackerId resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    ADEumHTTPRequestTracker *tracker = customRequestTrackers[trackerId];
    if (tracker) {
      [tracker reportDone];
    }
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to report request tracker", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(setRequestTrackerUserData:(NSString *)trackerId key:(NSString *)key value:(NSString *)value resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    ADEumHTTPRequestTracker *tracker = customRequestTrackers[trackerId];
    if (tracker) {
      [tracker setUserData:key value:value];
    }
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to set request tracker data", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(setRequestTrackerUserDataBoolean:(NSString *)trackerId key:(NSString *)key value:(BOOL)value resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    ADEumHTTPRequestTracker *tracker = customRequestTrackers[trackerId];
    if (tracker) {
      [tracker setUserDataBoolean:key value:value];
    }
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to set request tracker boolean data", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(setRequestTrackerUserDataDate:(NSString *)trackerId key:(NSString *)key value:(double)value resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    ADEumHTTPRequestTracker *tracker = customRequestTrackers[trackerId];
    if (tracker) {
      NSDate *date = [NSDate dateWithTimeIntervalSince1970:value / 1000];
      [tracker setUserDataDate:key value:date];
    }
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to set request tracker date data", e.reason, nil);
  }
}

RCT_EXPORT_METHOD(setRequestTrackerUserDataNumber:(NSString *)trackerId key:(NSString *)key value:(double)value resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    ADEumHTTPRequestTracker *tracker = customRequestTrackers[trackerId];
    if (tracker) {
      [tracker setUserDataDouble:key value:value];
    }
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to set request tracker number data", e.reason, nil);
  }
}

# pragma Other methods

RCT_EXPORT_METHOD(trackUIEvent: (NSDictionary *) eventInfo resolver:(RCTPromiseResolveBlock)resolve
                  rejecter:(RCTPromiseRejectBlock)reject) {
  try {
    int tag = [[eventInfo valueForKey:@"tag"] intValue];
    NSString *screenName = [eventInfo valueForKey:@"screenName"];
    NSString *eventName = [eventInfo valueForKey:@"eventName"];
    NSString *className = [eventInfo valueForKey:@"className"];
    NSString *label = [eventInfo valueForKey:@"label"];
    NSString *accessibility = [eventInfo valueForKey:@"accessibilityLabel"];
    NSString *index = [eventInfo valueForKey:@"index"];
    NSString *uiResponder = [eventInfo valueForKey:@"uiResponder"];

    NSDate *startTime = [NSDate date];
    [ADEumInstrumentation TrackUIEvent:screenName name:eventName class:className startTime:startTime label:label accessibility:accessibility tag:tag index:index uiResponder:uiResponder];
    resolve(nil);
  } catch (NSException *e) {
    reject(@"Failed to track UI event", e.reason, nil);
  }
}

@end
