"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ErrorSeverityLevel = void 0;
exports.reportError = reportError;
var _InstrumentationModule = _interopRequireDefault(require("../../native/InstrumentationModule.js"));
var _createCrashReport = require("./createCrashReport.js");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
var ErrorSeverityLevel = exports.ErrorSeverityLevel = function (ErrorSeverityLevel) {
  ErrorSeverityLevel[ErrorSeverityLevel["INFO"] = _InstrumentationModule.default.getConstants().ERROR_SEVERITY_LEVEL_INFO] = "INFO";
  ErrorSeverityLevel[ErrorSeverityLevel["WARNING"] = _InstrumentationModule.default.getConstants().ERROR_SEVERITY_LEVEL_WARNING] = "WARNING";
  ErrorSeverityLevel[ErrorSeverityLevel["CRITICAL"] = _InstrumentationModule.default.getConstants().ERROR_SEVERITY_LEVEL_CRITICAL] = "CRITICAL";
  return ErrorSeverityLevel;
}(ErrorSeverityLevel || {});
/**
 * Reports an error that was caught.
 *
 * This can be called in catch blocks to report interesting errors that you want to track.
 *
 * Valid severity levels:
 *
 * - {@link ErrorSeverityLevel.INFO}
 * - {@link ErrorSeverityLevel.WARNING}
 * - {@link ErrorSeverityLevel.CRITICAL}
 *
 * @param {Error} error the error to report
 * @param {ErrorSeverityLevel} severityLevel the error severity level
 */
async function reportError(error, severityLevel) {
  const hybridExceptionData = (0, _createCrashReport.createCrashReport)(error);
  const serialized = JSON.stringify(hybridExceptionData);
  await _InstrumentationModule.default.reportError(serialized, severityLevel);
}
//# sourceMappingURL=reportError.js.map