"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.removeUserDataDate = removeUserDataDate;
exports.setUserDataDate = setUserDataDate;
var _instrumentationHelpers = require("../utils/instrumentation-helpers.js");
var _InstrumentationModule = _interopRequireDefault(require("../../native/InstrumentationModule.js"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
// @ts-ignore
// eslint-disable-next-line @typescript-eslint/no-unused-vars
const {
  MAX_USER_DATA_STRING_LENGTH
} = _InstrumentationModule.default.getConstants();

/**
 * Sets a key-value pair identifier that will be included in all snapshots.
 * The identifier can be used to add any data you wish.
 *
 * The `key` must be unique across your application.
 * The `key` namespace is distinct for each user data type.
 * Re-using the same `key` overwrites the previous `value`.
 * The `key` is limited to @constant {MAX_USER_DATA_STRING_LENGTH} characters.
 *
 * A `value` of `null` will clear the data.
 *
 * This information is not persisted across application runs.  Once the application is destroyed,
 * the user data is cleared.
 *
 * @param {string} key Key for value.
 * @param {Date} value Date value.
 */
async function setUserDataDate(key, value) {
  if (!value) {
    return removeUserDataDate(key);
  }
  await _InstrumentationModule.default.setUserDataDate(key, (0, _instrumentationHelpers.serializeLongValue)(value.getTime()));
}

/**
 * Removes a key-value pair set with {@link setUserDataDate}.
 * The identifier can be used to add any data you wish.
 *
 * @param {string} key Key of the entry to remove.
 */
async function removeUserDataDate(key) {
  await _InstrumentationModule.default.removeUserDataDate(key);
}
//# sourceMappingURL=setUserDataDate.js.map