"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _InstrumentationModule = _interopRequireDefault(require("../../native/InstrumentationModule.js"));
var _package = require("../../../package.json");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * Initialize the agent with a given {@link AgentConfiguration}.
 *
 * The agent does not automatically start with your application. Using the app
 * key shown in your controller UI, you can initialize the agent. This has to be
 * done near your application's entry point before any other initialization
 * routines in your application (usually in `App`).
 *
 * ```tsx
 * import React, {useEffect} from 'react';
 * import {Text, View} from 'react-native';
 * import {Instrumentation, LoggingLevel} from '@appdynamics/react-native-agent';
 *
 * export default function App() {
 *  async function startInstrumentation() {
 *   await Instrumentation.start({
 *     appKey: '<MY-APP-KEY>',
 *     loggingLevel: LoggingLevel.VERBOSE,
 *   });
 *  }
 *
 *   useEffect(() => {
 *     startInstrumentation;
 *   }, []);
 *
 *   return (
 *     <View>
 *       <Text>My App</Text>
 *     </View>
 *   );
 * }
 * ```
 *
 * @param {AgentConfiguration} config The agent configuration to use.
 */
async function start(config) {
  const {
    crashReportCallback
  } = config;
  if (crashReportCallback) {
    await _InstrumentationModule.default.setCrashReportCallback(crashReportCallback);
  }
  await _InstrumentationModule.default.start(config, 'React Native', _package.version);
}
var _default = exports.default = start;
//# sourceMappingURL=start.js.map