"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.startSessionFrame = startSessionFrame;
var _InstrumentationModule = _interopRequireDefault(require("../../native/InstrumentationModule.js"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
// eslint-disable-next-line @typescript-eslint/no-unused-vars

/**
 * Object used to manually track custom screen frames throughout the app.
 *
 * @param {string} name Name of the new frame.
 * @see {@linkcode useScreenTracker} for a more specialized screen tracking mechanism.
 */
async function startSessionFrame(name) {
  const id = await _InstrumentationModule.default.startSessionFrame(name);

  /**
   * Updates the name of the session frame.
   * This is generally used when the best name for the Session Frame
   * is not known at the time of its creation.
   *
   * @param {string} newName New name for the tracked frame.
   */
  async function updateName(newName) {
    await _InstrumentationModule.default.updateSessionFrameName(id, newName);
  }

  /**
   * Reports the end of the session frame.
   * The {@link SessionFrame} object will no longer be useable after this call.
   * This method is thread safe.
   */
  async function end() {
    await _InstrumentationModule.default.endSessionFrame(id);
  }
  return {
    updateName,
    end
  };
}
//# sourceMappingURL=startSessionFrame.js.map