"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.startTimer = startTimer;
exports.stopTimer = stopTimer;
var _InstrumentationModule = _interopRequireDefault(require("../../native/InstrumentationModule.js"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * Starts a global timer with the given name.
 *
 * The name should contain only alphanumeric characters and spaces.
 *
 * Illegal characters will be replaced by their ASCII hex value.
 *
 * @param {string} name The name of the timer.
 *
 * ```tsx
 * async function doCheckout() {
 *   try {
 *     const CHECKOUT_TIMER = "Time Spent on checkout";
 *     await Instrumentation.startTimer(CHECKOUT_TIMER);
 *
 *     await someCheckoutService();
 *     await someOtherLongTask();
 *   catch (e) {
 *     // capture error
 *   } finally {
 *     await Instrumentation.stopTimer(CHECKOUT_TIMER);
 *   }
 * }
 * ```
 */
async function startTimer(name) {
  await _InstrumentationModule.default.startTimer(name);
}

/**
 * Stops a global timer with the given name and reports it to the cloud.
 *
 * The name should contain only alphanumeric characters and spaces.
 *
 * Illegal characters will be replaced by their ASCII hex value.
 *
 * @param {string} name The name of the timer.
 */
async function stopTimer(name) {
  await _InstrumentationModule.default.stopTimer(name);
}
//# sourceMappingURL=timers.js.map