"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.trackUIEvent = trackUIEvent;
var _InstrumentationModule = _interopRequireDefault(require("../../native/InstrumentationModule.js"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * Manually tracks UI events (button taps, TextView focused etc.).
 *
 * ```ts
 * import { Instrumentation } from "@appdynamics/react-native-agent";
 * import React, { View, Text, TouchableOpacity } from "react";
 *
 * function LoginScreen() {
 *   async function login() {
 *     try {
 *       await Instrumentation.trackUIEvent({
 *         screenName: "LoginScreen",
 *         eventName: "Login button press",
 *         className: "TouchableOpacity",
 *         label: "Proceed with login",
 *         accessibilityLabel: "loginButton",
 *         uiResponder: "loginCustomer",
 *       });
 *
 *       // customer login logic
 *     } catch (error) {
 *       // handle exception
 *     }
 *   }
 *
 *   return (
 *     <View>
 *       <TouchableOpacity accessibilityLabel="loginButton" onPress={login}>
 *         <Text>Proceed with login</Text>
 *       </TouchableOpacity>
 *     </View>
 *   );
 * }
 * ```
 *
 * @param {UIEventInfo} eventInfo Info regarding the event to be tracked.
 */
async function trackUIEvent(eventInfo) {
  await _InstrumentationModule.default.trackUIEvent(eventInfo);
}
//# sourceMappingURL=trackUIEvent.js.map