"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = require("react");
var _InstrumentationModule = _interopRequireDefault(require("../../native/InstrumentationModule.js"));
var _createCrashReport = require("../functions/createCrashReport.js");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * Custom React Error Boundary component that both captures and redirects events to the AppDynamics controller.
 *
 * @see https://reactjs.org/docs/error-boundaries.html
 */

/*
 * CDM-9426 TODO: convert to functional component when possible. Current docs recommend
 * class.
 */
class ErrorBoundary extends _react.Component {
  constructor(props) {
    super(props);
    this.state = {
      hasError: false
    };
  }
  static getDerivedStateFromError() {
    // Update state so the next render will show the fallback UI.
    return {
      hasError: true
    };
  }
  async componentDidCatch(error) {
    const hybridExceptionData = (0, _createCrashReport.createCrashReport)(error);
    const serialized = JSON.stringify(hybridExceptionData);
    await _InstrumentationModule.default.createCrashReport(serialized);
  }
  render() {
    const {
      fallbackUI,
      children
    } = this.props;
    const {
      hasError
    } = this.state;
    return hasError ? fallbackUI : children;
  }
}
var _default = exports.default = ErrorBoundary;
//# sourceMappingURL=ErrorBoundary.js.map