"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ScreenTrackerProvider = exports.ScreenTrackerContext = void 0;
var _react = _interopRequireWildcard(require("react"));
var _InstrumentationModule = _interopRequireDefault(require("../../native/InstrumentationModule.js"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
// eslint-disable-next-line @typescript-eslint/no-unused-vars

const ScreenTrackerContext = exports.ScreenTrackerContext = /*#__PURE__*/(0, _react.createContext)(null);
/**
 * Context that provides access to the {@linkcode useScreenTracker} hook.
 *
 * Wrap the topmost component that will consume `useScreenTracker`, ideally on
 * top of your `App` component:
 *
 * ```tsx
 * export default function App() {
 *
 *  // misc implementation
 *
 *  return (
 *    <ScreenTrackerProvider>
 *      <View>
 *        // rest of JSX tree
 *      </View>
 *    </ScreenTrackerProvider>
 *  );
 *  ```
 *
 * @param {React.ReactNode} props Your component's props.
 * @returns {React.ReactNode} Wrapper around your component.
 */
const ScreenTrackerProvider = props => {
  const trackedScreens = (0, _react.useRef)({});
  const trackScreenStart = (0, _react.useCallback)(async screenName => {
    const startDate = Date.now();
    const uuidString = await _InstrumentationModule.default.trackScreenStart({
      screenName,
      startDate
    });
    trackedScreens.current[screenName] = {
      screenName,
      startDate,
      uuidString
    };
  }, []);
  const trackScreenEnd = (0, _react.useCallback)(async screenName => {
    if (screenName in trackedScreens.current) {
      const trackedScreen = trackedScreens.current[screenName];
      const endDate = Date.now();
      const finalScreen = {
        endDate,
        ...trackedScreen
      };
      await _InstrumentationModule.default.trackScreenEnd(finalScreen);
      delete trackedScreens.current[screenName];
    }
  }, []);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(ScreenTrackerContext.Provider, {
    value: {
      trackScreenStart,
      trackScreenEnd
    },
    ...props
  });
};
exports.ScreenTrackerProvider = ScreenTrackerProvider;
//# sourceMappingURL=ScreenTrackerProvider.js.map