"use strict";

var _patchutil = require("./patchutil.js");
var _patches = require("./patches.js");
function help() {
  console.log('Usage: appd-react-native <install|uninstall|upgrade>');
}
function install() {
  const undoStack = [];
  function undoTempChanges() {
    for (const patch of undoStack) {
      try {
        (0, _patchutil.undoPatch)(patch);
      } catch (error) {
        console.error(error);
        console.error('[CRITICAL]: could not undo temporary modifications. You will have to fix your project files manually!');
      }
    }
  }
  try {
    for (const patch of _patches.PATCHES) {
      if ((0, _patchutil.applyPatch)(patch)) {
        undoStack.push(patch);
      }
    }
    console.log('Installation successful.');
  } catch (error) {
    console.error(error);
    console.error('[WARNING] Aborting automatic installation. Please refer to the documentation for manual instrumentation instructions.');
    undoTempChanges();
  }
}
function uninstall() {
  for (const patch of _patches.PATCHES) {
    try {
      (0, _patchutil.undoPatch)(patch);
      console.log('Successfully uninstalled appdynamics agent.');
    } catch (error) {
      if (error instanceof Error) {
        console.error(error.message);
      }
    }
  }
}

// `process.argv` is: [ 'path/to/node', 'path/to/script', 'command' ]
const argv = [...process.argv];
switch (argv[2]) {
  case 'install':
    {
      install();
      break;
    }
  case 'uninstall':
    {
      uninstall();
      break;
    }
  case 'upgrade':
    {
      uninstall();
      install();
      break;
    }
  default:
    {
      help();
    }
}
//# sourceMappingURL=cli.js.map