"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.applyPatch = applyPatch;
exports.undoPatch = undoPatch;
var fs = _interopRequireWildcard(require("node:fs"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * Applies a patch to a given file.
 *
 * @param patch
 * @returns true if the patch was applied, false if it was skipped.
 * @throws Error if there was a problem applying the patch
 */
function applyPatch(patch) {
  const fileContents = readTarget(patch.target);
  if (fileContents.includes(patch.payload)) {
    console.log(`Skipping patch "${patch.name}" because it is already applied.`);
    return false;
  }
  const injectionLocation = indexOfInjection(fileContents, patch.anchor);
  if (injectionLocation === undefined) {
    throw new Error(`Could not locate patch anchor for ${patch.name}!`);
  }
  const updated = fileContents.slice(0, Math.max(0, injectionLocation)) + patch.payload + fileContents.slice(injectionLocation);
  writeTarget(patch.target, updated);
  return true;
}

/**
 *
 * @param patch
 */
function undoPatch(patch) {
  const fileContents = readTarget(patch.target);
  const index = fileContents.indexOf(patch.payload);
  if (index < 0) {
    throw new Error(`Could not find the patch of ${patch.name}!`);
  }
  const updated = fileContents.slice(0, Math.max(0, index)) + fileContents.slice(index + patch.payload.length);
  writeTarget(patch.target, updated);
}

/**
 *
 * @param target
 */
function readTarget(target) {
  return fs.readFileSync(target).toString();
}

/**
 *
 * @param target
 * @param newContents
 */
function writeTarget(target, newContents) {
  return fs.writeFileSync(target, newContents);
}

/**
 * Finds the index at which to insert the patch.
 *
 * @param haystack
 * @param anchor
 * @returns The string index where to insert the patch, or undefined if it failed to find the location.
 */
function indexOfInjection(haystack, anchor) {
  const result = anchor.exec(haystack);
  if (result !== undefined) {
    return anchor.lastIndex;
  }
  return undefined;
}
//# sourceMappingURL=patchutil.js.map