"use strict";

import InstrumentationModule from "../../native/InstrumentationModule.js";
import { createCrashReport } from "./createCrashReport.js";
var ErrorSeverityLevel = function (ErrorSeverityLevel) {
  ErrorSeverityLevel[ErrorSeverityLevel["INFO"] = InstrumentationModule.getConstants().ERROR_SEVERITY_LEVEL_INFO] = "INFO";
  ErrorSeverityLevel[ErrorSeverityLevel["WARNING"] = InstrumentationModule.getConstants().ERROR_SEVERITY_LEVEL_WARNING] = "WARNING";
  ErrorSeverityLevel[ErrorSeverityLevel["CRITICAL"] = InstrumentationModule.getConstants().ERROR_SEVERITY_LEVEL_CRITICAL] = "CRITICAL";
  return ErrorSeverityLevel;
}(ErrorSeverityLevel || {});
/**
 * Reports an error that was caught.
 *
 * This can be called in catch blocks to report interesting errors that you want to track.
 *
 * Valid severity levels:
 *
 * - {@link ErrorSeverityLevel.INFO}
 * - {@link ErrorSeverityLevel.WARNING}
 * - {@link ErrorSeverityLevel.CRITICAL}
 *
 * @param {Error} error the error to report
 * @param {ErrorSeverityLevel} severityLevel the error severity level
 */
async function reportError(error, severityLevel) {
  const hybridExceptionData = createCrashReport(error);
  const serialized = JSON.stringify(hybridExceptionData);
  await InstrumentationModule.reportError(serialized, severityLevel);
}
export { reportError, ErrorSeverityLevel };
//# sourceMappingURL=reportError.js.map