"use strict";

import InstrumentationModule from "../../native/InstrumentationModule.js";

/**
 * Stops sending of beacons to the collector.
 *
 * No data will come from the agent while shut down. All other activities of
 * the agent will continue, except for event sending.
 *
 * See also {@link restartAgent}
 */
async function shutdownAgent() {
  await InstrumentationModule.shutdownAgent();
}

/**
 * Restarts sending of beacons to the collector.
 *
 * Data will start flowing from the agent immediately. No change will occur if
 * the shutdownAgent call has not been made.
 *
 * See also {@link shutdownAgent}
 */
async function restartAgent() {
  await InstrumentationModule.restartAgent();
}
export { restartAgent, shutdownAgent };
//# sourceMappingURL=shutdownRestart.js.map