"use strict";

import * as fs from 'node:fs';
/**
 * Applies a patch to a given file.
 *
 * @param patch
 * @returns true if the patch was applied, false if it was skipped.
 * @throws Error if there was a problem applying the patch
 */
export function applyPatch(patch) {
  const fileContents = readTarget(patch.target);
  if (fileContents.includes(patch.payload)) {
    console.log(`Skipping patch "${patch.name}" because it is already applied.`);
    return false;
  }
  const injectionLocation = indexOfInjection(fileContents, patch.anchor);
  if (injectionLocation === undefined) {
    throw new Error(`Could not locate patch anchor for ${patch.name}!`);
  }
  const updated = fileContents.slice(0, Math.max(0, injectionLocation)) + patch.payload + fileContents.slice(injectionLocation);
  writeTarget(patch.target, updated);
  return true;
}

/**
 *
 * @param patch
 */
export function undoPatch(patch) {
  const fileContents = readTarget(patch.target);
  const index = fileContents.indexOf(patch.payload);
  if (index < 0) {
    throw new Error(`Could not find the patch of ${patch.name}!`);
  }
  const updated = fileContents.slice(0, Math.max(0, index)) + fileContents.slice(index + patch.payload.length);
  writeTarget(patch.target, updated);
}

/**
 *
 * @param target
 */
function readTarget(target) {
  return fs.readFileSync(target).toString();
}

/**
 *
 * @param target
 * @param newContents
 */
function writeTarget(target, newContents) {
  return fs.writeFileSync(target, newContents);
}

/**
 * Finds the index at which to insert the patch.
 *
 * @param haystack
 * @param anchor
 * @returns The string index where to insert the patch, or undefined if it failed to find the location.
 */
function indexOfInjection(haystack, anchor) {
  const result = anchor.exec(haystack);
  if (result !== undefined) {
    return anchor.lastIndex;
  }
  return undefined;
}
//# sourceMappingURL=patchutil.js.map