/**
 * Unblocks screenshot capture if it is currently blocked. Otherwise, this has
 * no effect.
 *
 * If screenshots are disabled through {@link AgentConfiguration.screenshotsEnabled}
 * or through the controller UI, this method has no effect.
 *
 * If screenshots are set to manual mode in the controller UI, this method
 * unblocks for manual mode only.
 *
 * **Warning:** This will unblock capture for the entire app. Use the returned
 * promise to determine when screenshots have effectively been unblocked.
 *
 * The user is expected to manage any possible nesting issues that may
 * occur if blocking and unblocking occur in different code paths.
 */
declare function unblockScreenshots(): Promise<void>;
/**
 * Blocks screenshot capture if it is currently unblocked. Otherwise, this has
 * no effect.
 *
 * If screenshots are disabled through {@link AgentConfiguration.screenshotsEnabled}
 * or through the controller UI, this method has no effect.
 *
 * **Warning:** This will block capture for the entire app. Use the returned
 * promise to determine when screenshots have effectively been blocked.
 *
 * The user is expected to manage any possible nesting issues that may
 * occur if blocking and unblocking occur in different code paths.
 *
 * See {@link unblockScreenshots}
 */
declare function blockScreenshots(): Promise<void>;
/**
 * See {@link blockScreenshots}.
 *
 * @returns {boolean} Value whether screenshot capture is blocked.
 */
declare function screenshotsBlocked(): Promise<boolean>;
/**
 * Asynchronously takes a screenshot of the current screen.
 *
 * If screenshots are disabled through {@link AgentConfiguration.screenshotsEnabled}
 * or through the controller UI, this method does nothing.
 *
 * This will capture everything, including personal information, so you must be cautious of
 * when to take the screenshot.
 *
 * These screenshots will show up in the Sessions screen for this user.
 *
 * The screenshots are taken on a background thread, compressed, and only non-redundant parts
 * are uploaded, so it is safe to take many of these without impacting performance of your
 * application.
 */
declare function takeScreenshot(): Promise<void>;
export { takeScreenshot, screenshotsBlocked, blockScreenshots, unblockScreenshots, };
//# sourceMappingURL=screenshots.d.ts.map