export type TrackedScreen = {
    screenName: string;
    startDate: number;
    uuidString: string;
};
/**
 * WARNING: Planned deprecation.
 * Migrate to {@linkcode useScreenTracker} instead.
 * ---
 * Class used for manually tracking components throughout the app.
 *
 * The available methods permit specifying the start and end of a screen.
 * This will be reflected as an app screen in the controller.
 *
 * Some navigation libraries permit subscribing to root level methods where
 * you only have to implement this API only once, instead of in every screen:
 *
 * 1. {@link https://wix.github.io/react-native-navigation/docs/screen-lifecycle React Native navigation}
 * `componentDidAppear()` & `componentDidDisappear()`.
 *
 * 2. {@link https://reactnavigation.org/docs/screen-trackingReact React navigation}
 * `onStateChange()`.
 *
 * WARNING: Use unique screen names. Duplicate names might result in unexpected
 * behavior.
 *
 * ```tsx
 * import { ScreenTracker, useScreenTracker } from '@appdynamics/react-native-agent';
 *
 * class LoginScreen extends Component<{}> {
 *   async componentDidMount() {
 *     await ScreenTracker.getInstance().trackScreenStart('LoginScreen');
 *   }
 *
 *   async componentWillUnmount() {
 *     await ScreenTracker.getInstance().trackScreenEnd('LoginScreen');
 *   }
 *
 *   public render() {
 *     return (
 *       <View>
 *         <Text>My login screen.</Text>
 *       </View>
 *     );
 *   }
 * }
 * ```
 */
export declare class ScreenTracker {
    private static instance;
    private constructor();
    static getInstance(): ScreenTracker;
    private trackedScreens;
    trackScreenStart: (screenName: string) => Promise<void>;
    trackScreenEnd: (screenName: string) => Promise<void>;
}
//# sourceMappingURL=ScreenTracker.old.d.ts.map