import React from 'react';
interface ScreenTrackerContextProps {
    readonly trackScreenStart: (screenName: string) => void;
    readonly trackScreenEnd: (screenName: string) => void;
}
declare const ScreenTrackerContext: React.Context<ScreenTrackerContextProps | null>;
type TrackedScreen = {
    screenName: string;
    startDate: number;
    uuidString: string;
};
/**
 * Context that provides access to the {@linkcode useScreenTracker} hook.
 *
 * Wrap the topmost component that will consume `useScreenTracker`, ideally on
 * top of your `App` component:
 *
 * ```tsx
 * export default function App() {
 *
 *  // misc implementation
 *
 *  return (
 *    <ScreenTrackerProvider>
 *      <View>
 *        // rest of JSX tree
 *      </View>
 *    </ScreenTrackerProvider>
 *  );
 *  ```
 *
 * @param {React.ReactNode} props Your component's props.
 * @returns {React.ReactNode} Wrapper around your component.
 */
declare const ScreenTrackerProvider: (props: any) => React.JSX.Element;
export { type TrackedScreen, ScreenTrackerProvider, type ScreenTrackerContextProps, ScreenTrackerContext, };
//# sourceMappingURL=ScreenTrackerProvider.d.ts.map