declare enum ErrorSeverityLevel {
    /**
     * An error happened, but it did not cause a problem.
     */
    INFO,
    /**
     * An error happened but the app recovered gracefully.
     */
    WARNING,
    /**
     * An error happened and caused problems to the app.
     */
    CRITICAL
}
/**
 * Reports an error that was caught.
 *
 * This can be called in catch blocks to report interesting errors that you want to track.
 *
 * Valid severity levels:
 *
 * - {@link ErrorSeverityLevel.INFO}
 * - {@link ErrorSeverityLevel.WARNING}
 * - {@link ErrorSeverityLevel.CRITICAL}
 *
 * @param {Error} error the error to report
 * @param {ErrorSeverityLevel} severityLevel the error severity level
 */
declare function reportError(error: Error, severityLevel: ErrorSeverityLevel): Promise<void>;
export { reportError, ErrorSeverityLevel };
//# sourceMappingURL=reportError.d.ts.map