/**
 * Sets a key-value pair identifier that will be included in all snapshots.
 * The identifier can be used to add any data you wish.
 *
 * The `key` must be unique across your application.
 * The `key` namespace is distinct for each user data type.
 * Re-using the same `key` overwrites the previous `value`.
 * The `key` is limited to @constant {MAX_USER_DATA_STRING_LENGTH} characters.
 *
 * A `value` of `null` will clear the data.
 *
 * This information is not persisted across application runs.  Once the application is destroyed,
 * the user data is cleared.
 *
 * @param {string} key Key for value.
 * @param {string} value String value.
 */
declare function setUserData(key: string, value: string | null): Promise<void>;
/**
 * Removes a key-value pair set with {@link setUserDataString}.
 * The identifier can be used to add any data you wish.
 *
 * @param {string} key Key of the entry to remove.
 */
declare function removeUserData(key: string): Promise<void>;
export { setUserData, removeUserData };
//# sourceMappingURL=setUserData.d.ts.map