/**
 * Helps tracking functions and their implementation.
 *
 * The {@link InfoPoint} decorator provides an easier way to add info points to your app.
 * Consider using that as a first resort.
 *
 * ```tsx
 * async function downloadImage(url) {
 *   return Instrumentation.trackCall('DownloadService', 'downloadImage', [url], async () => {
 *     const request = createRequest(url);
 *     const response = await request.execute();
 *     if (response.status >= 400) {
 *       throw new Error(`Bad status code: ${response.status}`);
 *     }
 *   return response.data;
 *  });
 * ```
 *
 * @param {string} className Name of the class where the function is called.
 * @param {string} functionName Name of the class where the function is called.
 * @param {any[]} args Function's arguments.
 * @param {Function} executionCallback Function's implementation/body.
 */
declare function trackCall<T>(className: string, functionName: string, args: any[], executionCallback: () => T | Promise<T>): Promise<T>;
export default trackCall;
//# sourceMappingURL=trackCall.d.ts.map