interface ADError {
  message: string;
  stack: string;
}

function isPromise<T>(object: unknown): object is Promise<T> {
  return (
    object instanceof Object &&
    'then' in object &&
    typeof object.then === 'function'
  );
}
function convertToError(error: unknown | Error): ADError {
  if (error instanceof Error) {
    return {
      message: error.message || '',
      stack: error.stack || '',
    };
  }
  return {
    message: `${error}`,
    stack: '',
  };
}

function serializeLongValue(value: number): string {
  let finalValue = value;
  if (!Number.isInteger(value)) {
    finalValue = 0;
  }
  if (value > Number.MAX_SAFE_INTEGER) {
    finalValue = Number.MAX_SAFE_INTEGER;
  } else if (value < Number.MIN_SAFE_INTEGER) {
    finalValue = Number.MIN_SAFE_INTEGER;
  }
  return finalValue.toString(10);
}

export {isPromise, convertToError, serializeLongValue, type ADError};
