import type {TurboModule} from 'react-native';
import { TurboModuleRegistry } from 'react-native';
import type {
  Double,
  Float,
  Int32,
  UnsafeObject,
} from 'react-native/Libraries/Types/CodegenTypes';

/*
 * JavaScript spec files must be named Native<MODULE_NAME>.js,
 * and they export a TurboModuleRegistry Spec UnsafeObject.
 *
 * https://reactnative.dev/docs/new-architecture-library-intro?fabric-component-backward-compatibility=TypeScript
 */

/*
 * TODO: Change UnsafeObjects to real types (e.g. ADError, TrackedScreen) when TS
 * support for Codegen improves.
 *
 * Aim to be as specific as possible for stronger type-safety, even with other
 * types. Atm, there is no strong support to do better.
 */
export interface Spec extends TurboModule {
  readonly getConstants: () => {
    BREADCRUMB_VISIBILITY_CRASHES_AND_SESSIONS?: Int32;
    BREADCRUMB_VISIBILITY_CRASHES_ONLY?: Int32;
    ERROR_SEVERITY_LEVEL_CRITICAL?: Int32;
    ERROR_SEVERITY_LEVEL_INFO?: Int32;
    ERROR_SEVERITY_LEVEL_WARNING?: Int32;
    LOGGING_LEVEL_INFO?: Int32;
    LOGGING_LEVEL_NONE?: Int32;
    LOGGING_LEVEL_VERBOSE?: Int32;
    MAX_USER_DATA_STRING_LENGTH?: Int32;
  };
  beginCall(
    className: string,
    methodName: string,
    args: Array<string | boolean | Double | Float | Int32>,
    isStaticMethod: boolean,
  ): Promise<string>;
  endCallWithError(callId: string, error: UnsafeObject): Promise<void>;
  endCallWithSuccess(callId: string, data: UnsafeObject): Promise<void>;
  changeAppKey(appKey: string): Promise<void>;
  leaveBreadcrumb(breadcrumb: string, mode: Double): Promise<void>;
  reportError(hybridExceptionData: string, severityLevel: Double): Promise<void>;
  reportMetric(name: string, value: Double): Promise<void>;
  start(
    config: UnsafeObject,
    hybridAgentType: string,
    hybridAgentVersion: string,
  ): Promise<void>;
  setCrashReportCallback(cb: (summaries: UnsafeObject[]) => void): void;
  startNextSession(): Promise<void>;

  createCrashReport(report: string): Promise<void>;
  trackUIEvent(eventInfo: UnsafeObject): Promise<void>;

  // Screenshots
  takeScreenshot(): Promise<void>;
  unblockScreenshots(): Promise<void>;
  blockScreenshots(): Promise<void>;
  screenshotsBlocked(): Promise<boolean>;

  // Timers
  startTimer(name: string): Promise<void>;
  stopTimer(name: string): Promise<void>;

  // Agent shutdown and restart
  shutdownAgent(): Promise<void>;
  restartAgent(): Promise<void>;

  // Session frames
  startSessionFrame(sessionFrameName: string): Promise<string>;
  updateSessionFrameName(
    sessionFrameId: string,
    sessionFrameName: string,
  ): Promise<void>;
  endSessionFrame(sessionFrameId: string): Promise<void>;

  // Manual request tracking
  getServerCorrelationHeaders(): Promise<any>;
  getRequestTrackerWithUrl(urlString: string): Promise<string>;
  setRequestTrackerErrorInfo(
    trackerId: string,
    errorDict: UnsafeObject,
  ): Promise<void>;
  setRequestTrackerStatusCode(
    trackerId: string,
    statusCode: Double,
  ): Promise<void>;
  setRequestTrackerResponseHeaders(
    trackerId: string,
    responseHeaders: UnsafeObject,
  ): Promise<void>;
  setRequestTrackerRequestHeaders(
    trackerId: string,
    requestHeaders: UnsafeObject,
  ): Promise<void>;
  requestTrackerReport(id: string): Promise<void>;
  setRequestTrackerUserData(
    trackerId: string,
    key: string,
    value: string,
  ): Promise<void>;
  setRequestTrackerUserDataBoolean(
    trackerId: string,
    key: string,
    value: boolean,
  ): Promise<void>;
  setRequestTrackerUserDataNumber(
    trackerId: string,
    key: string,
    value: Double,
  ): Promise<void>;
  setRequestTrackerUserDataDate(
    trackerId: string,
    key: string,
    value: Double,
  ): Promise<void>;

  // Screen tracking
  trackScreenStart(trackedScreen: UnsafeObject): Promise<string>;
  trackScreenEnd(trackedScreen: UnsafeObject): Promise<void>;

  // User data
  setUserData(key: string, value: string): Promise<void>;
  removeUserData(key: string): Promise<void>;

  setUserDataBoolean(key: string, value: boolean): Promise<void>;
  removeUserDataBoolean(key: string): Promise<void>;

  setUserDataDate(key: string, value: string): Promise<void>;
  removeUserDataDate(key: string): Promise<void>;

  setUserDataNumber(key: string, value: Double): Promise<void>;
  removeUserDataNumber(key: string): Promise<void>;
}

export default TurboModuleRegistry.getEnforcing<Spec>('ReactNativeAppdynamics');
